@@ -236,18 +236,17 @@ void personal_photo_frame_button_press (GtkWidget *widget, GdkEventButton *event
 {
 	//g_warning ("%s", __PRETTY_FUNCTION__);
 	gboolean openImage = TRUE;
-	if (!self->priv->singleMode && self->priv->showSlideshowControls) {
+	//if (!self->priv->singleMode && self->priv->showSlideshowControls) {
+	if (!self->priv->singleMode) {
 		gdouble x_coord, y_coord;
 	
 		if (gdk_event_get_coords (event, &x_coord, &y_coord)) {
-			if (y_coord > self->priv->actualSize - 53.0) {
-				if (x_coord > self->priv->actualSize - 53.0) {
-					openImage = FALSE;
-					self->priv->rightArrowPressed = TRUE;
-				} else if (x_coord < 53.0) {
-					openImage = FALSE;
-					self->priv->leftArrowPressed = TRUE;
-				}
+			if (x_coord > self->priv->actualSize - 53.0) {
+				openImage = FALSE;
+				self->priv->rightArrowPressed = TRUE;
+			} else if (x_coord < 53.0) {
+				openImage = FALSE;
+				self->priv->leftArrowPressed = TRUE;
 			}
 		}
 	}
@@ -266,23 +265,22 @@ void personal_photo_frame_button_release (GtkWidget *widget, GdkEventButton *eve
 	self->priv->rightArrowPressed = FALSE;
 	gboolean openImage = TRUE;
 	
-	if (!self->priv->singleMode && self->priv->showSlideshowControls) {
+	//if (!self->priv->singleMode && self->priv->showSlideshowControls) {
+	if (!self->priv->singleMode) {
 		gdouble x_coord, y_coord;
 	
 		if (gdk_event_get_coords (event, &x_coord, &y_coord)) {
-			if (y_coord > self->priv->actualSize - 53.0) {
-				if (x_coord > self->priv->actualSize - 53.0) {
-					personal_photo_frame_update_content (self);
-					personal_photo_frame_remove_timers (self);
-					personal_photo_frame_add_timers (self);
-					openImage = FALSE;
-				} else if (x_coord < 53.0) {
-					self->priv->slideshowNum-=2;
-					personal_photo_frame_update_content (self);
-					personal_photo_frame_remove_timers (self);
-					personal_photo_frame_add_timers (self);
-					openImage = FALSE;
-				}
+			if (x_coord > self->priv->actualSize - 53.0) {
+				personal_photo_frame_update_content (self);
+				personal_photo_frame_remove_timers (self);
+				personal_photo_frame_add_timers (self);
+				openImage = FALSE;
+			} else if (x_coord < 53.0) {
+				self->priv->slideshowNum-=2;
+				personal_photo_frame_update_content (self);
+				personal_photo_frame_remove_timers (self);
+				personal_photo_frame_add_timers (self);
+				openImage = FALSE;
 			}
 		}
 	}
@@ -318,7 +316,7 @@ void personal_photo_frame_content_create (PersonalPhotoFrame *self)
 
 	gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), self->priv->event, TRUE, TRUE, 0);
 	
-	self->priv->image = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, self->priv->actualSize - 10, self->priv->actualSize - 10);
+	self->priv->image = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, self->priv->actualSize, self->priv->actualSize);
 	gdk_pixbuf_fill (self->priv->image, 0x00000000);
 	self->priv->backButton = gdk_pixbuf_new_from_file ("/usr/share/icons/hicolor/48x48/hildon/general_back.png", NULL);
 	self->priv->forwardButton = gdk_pixbuf_new_from_file ("/usr/share/icons/hicolor/48x48/hildon/general_forward.png", NULL);
@@ -362,10 +360,10 @@ void personal_photo_frame_update_content (PersonalPhotoFrame *self)
 
 	if (self->priv->singleMode) {
 		g_object_unref (self->priv->image);
-		self->priv->image = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, self->priv->actualSize - 10, self->priv->actualSize - 10);
+		self->priv->image = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, self->priv->actualSize, self->priv->actualSize);
 		gdk_pixbuf_fill (self->priv->image, 0x00000000);
 		
-		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale (self->priv->singleFilename, self->priv->actualSize - 10, self->priv->actualSize - 10, TRUE, NULL);
+		GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale (self->priv->singleFilename, self->priv->actualSize, self->priv->actualSize, TRUE, NULL);
 		if (pixbuf) {
 			ExifData *ed = exif_data_new_from_file (self->priv->singleFilename);
 			if (ed) {
@@ -403,13 +401,13 @@ void personal_photo_frame_update_content (PersonalPhotoFrame *self)
 					looped++;
 					g_dir_rewind (dir);
 					g_object_unref (self->priv->image);
-					self->priv->image = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, self->priv->actualSize - 10, self->priv->actualSize - 10);
+					self->priv->image = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, self->priv->actualSize, self->priv->actualSize);
 					gdk_pixbuf_fill (self->priv->image, 0x00000000);
 					gtk_widget_queue_draw (self);
 				} else {
 					self->priv->slideshowFilename = g_strconcat (self->priv->slideshowDirname, "/", filename, NULL);
 
-					GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale (self->priv->slideshowFilename, self->priv->actualSize - 10, self->priv->actualSize - 10, TRUE, NULL);
+					GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_scale (self->priv->slideshowFilename, self->priv->actualSize, self->priv->actualSize, TRUE, NULL);
 					if (pixbuf) {
 						ExifData *ed = exif_data_new_from_file (self->priv->slideshowFilename);
 						if (ed) {
@@ -436,7 +434,7 @@ void personal_photo_frame_update_content (PersonalPhotoFrame *self)
 			g_dir_close (dir);
 		} else {
 			g_object_unref (self->priv->image);
-			self->priv->image = gdk_pixbuf_new_from_file_at_scale ("/usr/share/icons/hicolor/scalable/hildon/personal-photo-frame.png", self->priv->actualSize - 10, self->priv->actualSize - 10, TRUE, NULL);
+			self->priv->image = gdk_pixbuf_new_from_file_at_scale ("/usr/share/icons/hicolor/scalable/hildon/personal-photo-frame.png", self->priv->actualSize, self->priv->actualSize, TRUE, NULL);
 		}
 	}
 }
@@ -681,7 +679,8 @@ static gboolean personal_photo_frame_expose_event (GtkWidget *widget, GdkEventEx
 	GdkColor color;
 	if (!self->priv->isPressed) {
 		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.75);
+		//cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.75);
+		cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.0);
 	} else {
 		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
 		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
@@ -693,98 +692,118 @@ static gboolean personal_photo_frame_expose_event (GtkWidget *widget, GdkEventEx
 	height = widget->allocation.height;
 	x = widget->allocation.x;
 	y = widget->allocation.y;
+	gint pixbufWidth=gdk_pixbuf_get_width(self->priv->image);
+	gint pixbufHeight=gdk_pixbuf_get_height(self->priv->image);
+	gint leftPos = ((width - pixbufWidth)/2);
+	gint topPos = ((height - pixbufHeight)/2);
 
-	cairo_move_to(cr, x + radius, y);
-	cairo_line_to(cr, x + width - radius, y);
-	cairo_curve_to(cr, x + width - radius, y, x + width, y, x + width,
-				y + radius);
-	cairo_line_to(cr, x + width, y + height - radius);
-	cairo_curve_to(cr, x + width, y + height - radius, x + width,
-				y + height, x + width - radius, y + height);
-	cairo_line_to(cr, x + radius, y + height);
-	cairo_curve_to(cr, x + radius, y + height, x, y + height, x,
-				y + height - radius);
-	cairo_line_to(cr, x, y + radius);
-	cairo_curve_to(cr, x, y + radius, x, y, x + radius, y);
+	cairo_move_to(cr, leftPos + radius, topPos);
+	cairo_line_to(cr, leftPos + pixbufWidth - radius, topPos);
+	cairo_curve_to(cr, leftPos + pixbufWidth - radius, topPos, leftPos + pixbufWidth, topPos, leftPos + pixbufWidth,
+				topPos + radius);
+	cairo_line_to(cr, leftPos + pixbufWidth, topPos + pixbufHeight - radius);
+	cairo_curve_to(cr, leftPos + pixbufWidth, topPos + pixbufHeight - radius, leftPos + pixbufWidth,
+				topPos + pixbufHeight, leftPos + pixbufWidth - radius, topPos + pixbufHeight);
+	cairo_line_to(cr, leftPos + radius, topPos + pixbufHeight);
+	cairo_curve_to(cr, leftPos + radius, topPos + pixbufHeight, leftPos, topPos + pixbufHeight, leftPos,
+				topPos + pixbufHeight - radius);
+	cairo_line_to(cr, leftPos, topPos + radius);
+	cairo_curve_to(cr, leftPos, topPos + radius, leftPos, topPos, leftPos + radius, topPos);
 
 	cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
 
-	cairo_fill_preserve(cr);
+	//cairo_fill_preserve(cr);
 	
-	gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
-	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
-	cairo_set_line_width (cr, 1);
-	cairo_stroke (cr);
+	//gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
+	//cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
+	//cairo_set_line_width (cr, 1);
+	//cairo_stroke (cr);
+	cairo_fill (cr);
 	
-	gint pixbufWidth=gdk_pixbuf_get_width(self->priv->image);
-	gint pixbufHeight=gdk_pixbuf_get_height(self->priv->image);
-	gint leftPos = 5 + ((width - 10 - pixbufWidth)/2);
-	gint topPos = 5 + ((height - 10 - pixbufHeight)/2);
+
 	gdk_cairo_set_source_pixbuf (cr, self->priv->image, leftPos, topPos);
 	cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
 	if (!self->priv->isPressed) {
 		cairo_paint (cr);
 	} else {
-		cairo_paint_with_alpha (cr, 0.75);
+		cairo_paint_with_alpha (cr, 0.5);
 	}
 	
-	cairo_move_to (cr, leftPos -1, topPos -1);
-	cairo_line_to (cr, leftPos, topPos + 1 + pixbufHeight);
-	cairo_line_to (cr, leftPos + 1 + pixbufWidth, topPos + 1 + pixbufHeight);
-	cairo_line_to (cr, leftPos + 1 + pixbufWidth, topPos - 1);
-	cairo_line_to (cr, leftPos, topPos);
+	//cairo_move_to (cr, leftPos -1, topPos -1);
+	//cairo_line_to (cr, leftPos, topPos + 1 + pixbufHeight);
+	//cairo_line_to (cr, leftPos + 1 + pixbufWidth, topPos + 1 + pixbufHeight);
+	//cairo_line_to (cr, leftPos + 1 + pixbufWidth, topPos - 1);
+	//cairo_line_to (cr, leftPos, topPos);
 	
-	gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
-	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
-	cairo_set_line_width (cr, 1);
-	cairo_stroke (cr);
+	//gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
+	//cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
+	//cairo_set_line_width (cr, 1);
+	//cairo_stroke (cr);
 	
-	cairo_destroy(cr);
+	//cairo_destroy(cr);
 	
 	if (!self->priv->singleMode && self->priv->showSlideshowControls) {
-		cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
-		gdk_cairo_set_source_pixbuf (cr, self->priv->backButton, 5, height - 53);
-		cairo_paint_with_alpha (cr, 0.5);
+		//cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
 		
-		gdk_cairo_set_source_pixbuf (cr, self->priv->forwardButton, width - 58, height - 53);
-		cairo_paint_with_alpha (cr, 0.5);
+		cairo_move_to (cr, 5, height / 2 - 24);
+		cairo_line_to (cr, 5, height / 2 + 24);
+		cairo_line_to (cr, 53, height / 2 + 24);
+		cairo_line_to (cr, 53, height / 2 - 24);
+		cairo_line_to (cr, 5, height / 2 -24);
+		cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.4);
+		cairo_fill (cr);
 		
-		cairo_move_to (cr, 0, height - 58);
-		cairo_line_to (cr, 0, height);
-		cairo_line_to (cr, 58, height);
-		cairo_line_to (cr, 58, height - 58);
-		cairo_line_to (cr, 0, height - 58);
+		cairo_move_to (cr, width - 58, height / 2 - 24);
+		cairo_line_to (cr, width - 58, height / 2 + 24);
+		cairo_line_to (cr, width - 5, height / 2 + 24);
+		cairo_line_to (cr, width - 5, height / 2 - 24);
+		cairo_line_to (cr, width - 58, height / 2 -24);
+		cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.4);
+		cairo_fill (cr);
 		
-		if (self->priv->leftArrowPressed) {
-			gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
-			cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
-			cairo_fill_preserve (cr);
-		}
+		gdk_cairo_set_source_pixbuf (cr, self->priv->backButton, 5, height /2 - 24);
+		cairo_paint_with_alpha (cr, 0.75);
 		
-		gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.25);
-		cairo_set_line_width (cr, 1);
-		cairo_stroke (cr);
-		
-		cairo_move_to (cr, width - 58, height - 58);
-		cairo_line_to (cr, width - 58, height);
-		cairo_line_to (cr, width, height);
-		cairo_line_to (cr, width, height - 58);
-		cairo_line_to (cr, width - 58, height - 58);
-		
-		if (self->priv->rightArrowPressed) {
-			gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
-			cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
-			cairo_fill_preserve (cr);
-		}
-		
-		gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
-		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.25);
-		cairo_set_line_width (cr, 1);
-		cairo_stroke (cr);
-		
-		cairo_destroy (cr);
+		gdk_cairo_set_source_pixbuf (cr, self->priv->forwardButton, width - 53, height /2 - 24);
+		cairo_paint_with_alpha (cr, 0.75);
 	}
+		
+	cairo_move_to (cr, 0, topPos);
+	cairo_line_to (cr, 0, topPos + pixbufHeight);
+	cairo_line_to (cr, 58, topPos + pixbufHeight);
+	cairo_line_to (cr, 58, topPos);
+	cairo_line_to (cr, 0, topPos);
+	
+	if (self->priv->leftArrowPressed) {
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+		cairo_fill_preserve (cr);
+	}
+	
+	//gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
+	//cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.25);
+	//cairo_set_line_width (cr, 1);
+	//cairo_stroke (cr);
+	
+	cairo_new_path (cr);
+	cairo_move_to (cr, width - 58, topPos);
+	cairo_line_to (cr, width - 58, topPos + pixbufHeight);
+	cairo_line_to (cr, width, topPos + pixbufHeight);
+	cairo_line_to (cr, width, topPos);
+	cairo_line_to (cr, width - 58, topPos);
+	
+	if (self->priv->rightArrowPressed) {
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+		cairo_fill_preserve (cr);
+	}
+	
+	//gtk_style_lookup_color (gtk_rc_get_style(widget), "ActiveTextColor", &color);
+	//cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.25);
+	//cairo_set_line_width (cr, 1);
+	//cairo_stroke (cr);
+		
+	cairo_destroy (cr);
 	
 	return GTK_WIDGET_CLASS (personal_photo_frame_parent_class)->expose_event (widget, event);
 }
